package VMOMI::EventEventSeverity;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
